@@ -1,7 +1,7 @@
 /*
  * dict.c	Routines to read the dictionary file.
  *
- * Version:	$Id: dict.c,v 1.50.2.4.2.2 2006/01/09 23:02:47 aland Exp $
+ * Version:	$Id: dict.c,v 1.50.2.4.2.4 2006/03/15 15:37:54 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,12 +15,12 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.2 2006/01/09 23:02:47 aland Exp $";
+static const char rcsid[] = "$Id: dict.c,v 1.50.2.4.2.4 2006/03/15 15:37:54 nbk Exp $";
 
 #include	"autoconf.h"
 
@@ -1207,7 +1207,7 @@ DICT_VALUE *dict_valbyname(int attr, const char *name)
 	if (!name) return NULL;
 
 	hash = dict_hashname(name);
-	hash = lrad_hash_update(&attr, sizeof(&attr), hash);
+	hash = lrad_hash_update(&attr, sizeof(attr), hash);
 
 	return lrad_hash_table_finddata(values_byname, hash);
 }
