@@ -1,7 +1,7 @@
 /*
  * filters.c	Routines to parse Ascend's filter attributes.
  *
- * Version:	$Id: filters.c,v 1.36 2004/02/26 19:04:20 aland Exp $
+ * Version:	$Id: filters.c,v 1.36.4.1 2006/03/15 15:37:54 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,12 +15,12 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2003  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: filters.c,v 1.36 2004/02/26 19:04:20 aland Exp $";
+static const char rcsid[] = "$Id: filters.c,v 1.36.4.1 2006/03/15 15:37:54 nbk Exp $";
 
 #include <string.h>
 #include <ctype.h>
