@@ -1,7 +1,7 @@
 /*
  * misc.c	Various miscellaneous functions.
  *
- * Version:	$Id: misc.c,v 1.41.2.3.2.1 2005/12/12 23:28:29 aland Exp $
+ * Version:	$Id: misc.c,v 1.41.2.3.2.2 2006/03/15 15:37:56 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,13 +15,13 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2000  The FreeRADIUS server project
  */
 
 static const char rcsid[] =
-"$Id: misc.c,v 1.41.2.3.2.1 2005/12/12 23:28:29 aland Exp $";
+"$Id: misc.c,v 1.41.2.3.2.2 2006/03/15 15:37:56 nbk Exp $";
 
 #include	"autoconf.h"
 
