@@ -1,7 +1,7 @@
 /*
  * radius.c	Functions to send/receive radius packets.
  *
- * Version:	$Id: radius.c,v 1.125.2.5.2.3 2005/12/19 19:42:38 aland Exp $
+ * Version:	$Id: radius.c,v 1.125.2.5.2.5 2006/03/15 15:37:57 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,12 +15,12 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2000-2003  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: radius.c,v 1.125.2.5.2.3 2005/12/19 19:42:38 aland Exp $";
+static const char rcsid[] = "$Id: radius.c,v 1.125.2.5.2.5 2006/03/15 15:37:57 nbk Exp $";
 
 #include	"autoconf.h"
 #include	"md5.h"
@@ -132,9 +132,9 @@ static const char *packet_codes[] = {
   "Disconnect-Request",
   "Disconnect-ACK",
   "Disconnect-NAK",
-  "CoF-Request",
-  "CoF-ACK",
-  "CoF-NAK",
+  "CoA-Request",
+  "CoA-ACK",
+  "CoA-NAK",
   "46",
   "47",
   "48",
@@ -606,6 +606,7 @@ int rad_encode(RADIUS_PACKET *packet, const RADIUS_PACKET *original,
 		 */
 	case PW_ACCOUNTING_REQUEST:
 	case PW_DISCONNECT_REQUEST:
+	case PW_COA_REQUEST:
 		memset(packet->vector, 0, sizeof(packet->vector));
 		break;
 		
@@ -753,9 +754,9 @@ int rad_sign(RADIUS_PACKET *packet, const RADIUS_PACKET *original,
 		case PW_DISCONNECT_REQUEST:
 		case PW_DISCONNECT_ACK:
 		case PW_DISCONNECT_NAK:
-		case PW_COF_REQUEST:
-		case PW_COF_ACK:
-		case PW_COF_NAK:
+		case PW_COA_REQUEST:
+		case PW_COA_ACK:
+		case PW_COA_NAK:
 			memset(hdr->vector, 0, AUTH_VECTOR_LEN);
 			break;
 
@@ -1397,9 +1398,9 @@ static int rad_verify(RADIUS_PACKET *packet, RADIUS_PACKET *original,
 			case PW_DISCONNECT_REQUEST:
 			case PW_DISCONNECT_ACK:
 			case PW_DISCONNECT_NAK:
-			case PW_COF_REQUEST:
-			case PW_COF_ACK:
-			case PW_COF_NAK:
+			case PW_COA_REQUEST:
+			case PW_COA_ACK:
+			case PW_COA_NAK:
 			  	memset(packet->data + 4, 0, AUTH_VECTOR_LEN);
 				break;
 
