@@ -1,7 +1,7 @@
 /*
  * valuepair.c	Functions to handle VALUE_PAIRs
  *
- * Version:	$Id: valuepair.c,v 1.82.2.1 2004/12/03 18:43:32 aland Exp $
+ * Version:	$Id: valuepair.c,v 1.82.2.1.2.1 2006/03/15 15:37:58 nbk Exp $
  *
  *   This library is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU Lesser General Public
@@ -15,12 +15,12 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
+ *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1 2004/12/03 18:43:32 aland Exp $";
+static const char rcsid[] = "$Id: valuepair.c,v 1.82.2.1.2.1 2006/03/15 15:37:58 nbk Exp $";
 
 #include	"autoconf.h"
 
