@@ -1,7 +1,7 @@
 /*
  * mainconf.c	Handle the server's configuration.
  *
- * Version:	$Id: mainconfig.c,v 1.36.2.6 2005/08/24 15:38:26 nbk Exp $
+ * Version:	$Id: mainconfig.c,v 1.36.2.6.2.1 2006/02/07 09:43:27 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -1274,7 +1274,7 @@ int read_mainconfig(int reload)
 		    (radlog_dir == NULL)) {
 			radlog(L_ERR|L_CONS, "Errors reading radiusd.conf");
 		} else {
-			radlog(L_ERR|L_CONS, "Errors reading %s/radiusd.conf: For more information, please read the tail end of %s", radlog_dir, mainconfig.log_file);
+			radlog(L_ERR|L_CONS, "Errors reading %s/radiusd.conf: For more information, please read the tail end of %s", radius_dir, mainconfig.log_file);
 		}
 		return -1;
 	}
