@@ -1,7 +1,7 @@
 /*
  * modules.c	Radius module support.
  *
- * Version:	$Id: modules.c,v 1.86.2.1 2004/11/11 01:21:10 aland Exp $
+ * Version:	$Id: modules.c,v 1.86.2.1.2.2 2006/01/09 23:06:26 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  * Copyright 2000  Alan Curry <pacman@world.std.com>
  */
 
-static const char rcsid[] = "$Id: modules.c,v 1.86.2.1 2004/11/11 01:21:10 aland Exp $";
+static const char rcsid[] = "$Id: modules.c,v 1.86.2.1.2.2 2006/01/09 23:06:26 aland Exp $";
 
 #include "autoconf.h"
 #include "libradius.h"
@@ -481,6 +481,9 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp,
 	static int meaningless_counter = 1;
 
 	ml = compile_modgroup(comp, cs, filename);
+	if (!ml) {
+		return; /* FIXME: pull full fix from CVS head */
+	}
 
 	/* We must assign a numeric index to this subcomponent. For
 	 * auth, it is generated and placed in the dictionary by
@@ -498,6 +501,10 @@ static void load_subcomponent_section(CONF_SECTION *cs, int comp,
 		dval = dict_valbyname(PW_ACCT_TYPE, cf_section_name2(cs));
 	} else if (comp == RLM_COMPONENT_SESS) {
 		dval = dict_valbyname(PW_SESSION_TYPE, cf_section_name2(cs));
+	} else if (comp == RLM_COMPONENT_PRE_PROXY) {
+		dval = dict_valbyname(PW_PRE_PROXY_TYPE, cf_section_name2(cs));
+	} else if (comp == RLM_COMPONENT_POST_PROXY) {
+		dval = dict_valbyname(PW_POST_PROXY_TYPE, cf_section_name2(cs));
 	} else if (comp == RLM_COMPONENT_POST_AUTH) {
 		dval = dict_valbyname(PW_POST_AUTH_TYPE, cf_section_name2(cs));
 	}
@@ -560,12 +567,15 @@ static int load_component_section(CONF_SECTION *cs, int comp,
 			cp = cf_itemtopair(modref);
 		}
 
-		/*
-		 *	FIXME: This calls exit if the reference can't be
-		 *	found.  We should instead print a better error,
-		 *	and return the failure code up the stack.
-		 */
 		this = compile_modsingle(comp, modref, filename, &modname);
+                if (!this) {
+                        radlog(L_ERR|L_CONS,
+                               "%s[%d] Failed to parse %s section.\n",
+                               filename, cf_section_lineno(cs),
+                               cf_section_name1(cs));
+                        return -1;
+                }
+
 
 		if (comp == RLM_COMPONENT_AUTH) {
 			DICT_VALUE *dval;
@@ -939,17 +949,17 @@ int module_checksimul(int sess_type, REQUEST *request, int maxsimul)
 /*
  *	Do pre-proxying for ALL configured sessions
  */
-int module_pre_proxy(REQUEST *request)
+int module_pre_proxy(int type, REQUEST *request)
 {
-	return indexed_modcall(RLM_COMPONENT_PRE_PROXY, 0, request);
+	return indexed_modcall(RLM_COMPONENT_PRE_PROXY, type, request);
 }
 
 /*
  *	Do post-proxying for ALL configured sessions
  */
-int module_post_proxy(REQUEST *request)
+int module_post_proxy(int type, REQUEST *request)
 {
-	return indexed_modcall(RLM_COMPONENT_POST_PROXY, 0, request);
+	return indexed_modcall(RLM_COMPONENT_POST_PROXY, type, request);
 }
 
 /*
