@@ -1,7 +1,7 @@
 /*
  * radclient.c	General radius packet debug tool.
  *
- * Version:	$Id: radclient.c,v 1.72.2.1.2.3 2005/12/08 11:13:49 nbk Exp $
+ * Version:	$Id: radclient.c,v 1.72.2.1.2.4 2006/03/07 18:10:10 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Copyright 2000  Miquel van Smoorenburg <miquels@cistron.nl>
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
-static const char rcsid[] = "$Id: radclient.c,v 1.72.2.1.2.3 2005/12/08 11:13:49 nbk Exp $";
+static const char rcsid[] = "$Id: radclient.c,v 1.72.2.1.2.4 2006/03/07 18:10:10 aland Exp $";
 
 #include "autoconf.h"
 
@@ -102,7 +102,7 @@ static void NEVER_RETURNS usage(void)
 {
 	fprintf(stderr, "Usage: radclient [options] server[:port] <command> [<secret>]\n");
 
-	fprintf(stderr, "  <command>    One of auth, acct, status, or disconnect.\n");
+	fprintf(stderr, "  <command>    One of auth, acct, status, coa, or disconnect.\n");
 	fprintf(stderr, "  -c count    Send each packet 'count' times.\n");
 	fprintf(stderr, "  -d raddb    Set dictionary directory.\n");
 	fprintf(stderr, "  -f file     Read packets from file, not stdin.\n");
@@ -788,7 +788,7 @@ int main(int argc, char **argv)
 			timeout = atof(optarg);
 			break;
 		case 'v':
-			printf("radclient: $Id: radclient.c,v 1.72.2.1.2.3 2005/12/08 11:13:49 nbk Exp $ built on " __DATE__ " at " __TIME__ "\n");
+			printf("radclient: $Id: radclient.c,v 1.72.2.1.2.4 2006/03/07 18:10:10 aland Exp $ built on " __DATE__ " at " __TIME__ "\n");
 			exit(0);
 			break;
 		case 'x':
@@ -857,6 +857,10 @@ int main(int argc, char **argv)
 		if (server_port == 0) server_port = PW_POD_UDP_PORT;
 		packet_code = PW_DISCONNECT_REQUEST;
 
+	} else if (strcmp(argv[2], "coa") == 0) {
+		if (server_port == 0) server_port = PW_POD_UDP_PORT;
+		packet_code = PW_COA_REQUEST;
+
 	} else if (strcmp(argv[2], "auto") == 0) {
 		packet_code = -1;
 
