@@ -1,7 +1,7 @@
 /*
  * session.c	session management
  *
- * Version:	$Id: session.c,v 1.21 2003/07/23 19:50:39 aland Exp $
+ * Version:	$Id: session.c,v 1.21.2.1 2005/03/17 13:52:44 phampson Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -127,7 +127,7 @@ int rad_check_ts(uint32_t nasaddr, unsigned int portnum, const char *user,
 	int	status;
 	int	n;
 	char	address[16];
-	char	port[8];
+	char	port[11];
 	RADCLIENT *cl;
 
 	/*
@@ -212,7 +212,7 @@ int rad_check_ts(uint32_t nasaddr, unsigned int portnum, const char *user,
 	 */
 
 	ip_ntoa(address, nasaddr);
-	sprintf(port, "%u", portnum);
+	snprintf(port, 11, "%u", portnum);
 
 #ifdef __EMX__
 	/* OS/2 can't directly execute scripts then we call the command
