@@ -1,7 +1,7 @@
 /*
  * rlm_detail.c	accounting:    Write the "detail" files.
  *
- * Version:	$Id: rlm_detail.c,v 1.37 2004/02/26 19:04:28 aland Exp $
+ * Version:	$Id: rlm_detail.c,v 1.37.2.1 2005/08/17 17:50:10 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  * Copyright 2000  The FreeRADIUS server project
  */
 
-static const char rcsid[] = "$Id: rlm_detail.c,v 1.37 2004/02/26 19:04:28 aland Exp $";
+static const char rcsid[] = "$Id: rlm_detail.c,v 1.37.2.1 2005/08/17 17:50:10 aland Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -177,16 +177,21 @@ static int do_detail(void *instance, REQUEST *request, RADIUS_PACKET *packet,
 				inst->last_made_directory = NULL;
 			}
 
-			/*
-			 *	Go create possibly multiple directories.
-			 */
-			if (rad_mkdir(buffer, inst->dirperm) < 0) {
-				radlog(L_ERR, "rlm_detail: Failed to create directory %s: %s", buffer, strerror(errno));
-				return RLM_MODULE_FAIL;
-			}
 			inst->last_made_directory = strdup(buffer);
 		}
 
+		/*
+		 *	stat the directory, and don't do anything if
+		 *	it exists.  If it doesn't exist, create it.
+		 *
+		 *	This also catches the case where some idiot
+		 *	deleted a directory that the server was using.
+		 */
+		if (rad_mkdir(inst->last_made_directory, inst->dirperm) < 0) {
+			radlog(L_ERR, "rlm_detail: Failed to create directory %s: %s", inst->last_made_directory, strerror(errno));
+			return RLM_MODULE_FAIL;
+		}
+
 		*p = '/';
 	} /* else there was no directory delimiter. */
 
