@@ -1,7 +1,7 @@
 /*
  * rlm_chap.c
  *
- * Version:  $Id: rlm_digest.c,v 1.5.4.2 2005/12/20 00:51:16 aland Exp $
+ * Version:  $Id: rlm_digest.c,v 1.5.4.4 2006/03/06 19:02:58 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include "modules.h"
 #include "conffile.h"
 
-static const char rcsid[] = "$Id: rlm_digest.c,v 1.5.4.2 2005/12/20 00:51:16 aland Exp $";
+static const char rcsid[] = "$Id: rlm_digest.c,v 1.5.4.4 2006/03/06 19:02:58 aland Exp $";
 
 static int digest_authorize(void *instance, REQUEST *request)
 {
@@ -96,10 +96,15 @@ static int digest_authenticate(void *instance, REQUEST *request)
 	/*
 	 *	We require access to the plain-text password.
 	 */
-	passwd = pairfind(request->config_items, PW_PASSWORD);
-#ifdef PW_MD5_PASSWORD
- 	if (!passwd) passwd = pairfind(request->config_items, PW_MD5_PASSWORD);
-#endif
+	passwd = pairfind(request->config_items, PW_DIGEST_HA1);
+	if (passwd) {
+		if (passwd->length != 32) {
+			radlog(L_AUTH, "rlm_digest: Digest-HA1 has invalid length, authentication failed.");
+			return RLM_MODULE_INVALID;
+		}
+	} else {
+		passwd = pairfind(request->config_items, PW_PASSWORD);
+	}
 	if (!passwd) {
 		radlog(L_AUTH, "rlm_digest: Configuration item \"User-Password\" or MD5-Password is required for authentication.");
 		return RLM_MODULE_INVALID;
@@ -236,7 +241,7 @@ static int digest_authenticate(void *instance, REQUEST *request)
 		DEBUG2("A1 = %s", a1);
 	} else {
 		a1[a1_len] = '\0';
-		DEBUG2("A1 = %s (using MD5-Password)", a1);
+		DEBUG2("A1 = %s (using Digest-HA1)", a1);
 		a1_len = 16;
 	}
 
@@ -248,24 +253,24 @@ static int digest_authenticate(void *instance, REQUEST *request)
 	if ((algo == NULL) || 
 	    (strcasecmp(algo->strvalue, "MD5") == 0)) {
 		/*
-		 *	Set A1 to MD5-Password if no User-Password found
+		 *	Set A1 to Digest-HA1 if no User-Password found
 		 */
-		if (passwd->attribute != PW_USER_PASSWORD) {
-			memcpy(&a1[0], passwd->strvalue, 16);
+		if (passwd->attribute == PW_DIGEST_HA1) {
+			lrad_hex2bin(passwd->strvalue, &a1[0], 16);
 		}
 
 	} else if (strcasecmp(algo->strvalue, "MD5-sess") == 0) {
 		/*
 		 *	K1 = H(A1) : Digest-Nonce ... : H(A2)
 		 *
-		 *	If we find MD5-Password, we assume it contains
+		 *	If we find Digest-HA1, we assume it contains
 		 *	H(A1).
 		 */
 		if (passwd->attribute == PW_USER_PASSWORD) {
 			librad_md5_calc(hash, &a1[0], a1_len);
 			lrad_bin2hex(hash, &a1[0], 16);
-		} else {
-			lrad_bin2hex(passwd->strvalue, &a1[0], 16);
+		} else {	/* MUST be Digest-HA1 */
+			memcpy(&a1[0], passwd->strvalue, 32);
 		}
 		a1_len = 32;
 
