@@ -1,7 +1,7 @@
 /*
  * radeapclient.c	EAP specific radius packet debug tool.
  *
- * Version:	$Id: radeapclient.c,v 1.7.4.1 2005/12/14 18:32:02 nbk Exp $
+ * Version:	$Id: radeapclient.c,v 1.7.4.2 2006/02/06 16:23:51 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,10 +21,9 @@
  * Copyright 2000  Miquel van Smoorenburg <miquels@cistron.nl>
  * Copyright 2000  Alan DeKok <aland@ox.org>
  */
-static const char rcsid[] = "$Id: radeapclient.c,v 1.7.4.1 2005/12/14 18:32:02 nbk Exp $";
+static const char rcsid[] = "$Id: radeapclient.c,v 1.7.4.2 2006/02/06 16:23:51 nbk Exp $";
 
 #include "autoconf.h"
-#include "libradius.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -53,7 +52,7 @@ static const char rcsid[] = "$Id: radeapclient.c,v 1.7.4.1 2005/12/14 18:32:02 n
 #include "conf.h"
 #include "radpaths.h"
 #include "missing.h"
-#include "../include/md5.h"
+#include "../../include/md5.h"
 
 #include "eap_types.h"
 #include "eap_sim.h"
@@ -164,7 +163,7 @@ static int send_packet(RADIUS_PACKET *req, RADIUS_PACKET **rep)
 
 				ip_ntoa(src, (*rep)->src_ipaddr);
 				ip_ntoa(dst, req->dst_ipaddr);
-				fprintf(stderr, "radclient: ERROR: Sent request to host %s:%d, got response from host %s:%d\n!",
+				fprintf(stderr, "radclient: ERROR: Sent request to host %s port %d, got response from host %s port %d\n!",
 					dst, req->dst_port,
 					src, (*rep)->src_port);
 				exit(1);
@@ -182,6 +181,12 @@ static int send_packet(RADIUS_PACKET *req, RADIUS_PACKET **rep)
 		exit(1);
 	}
 
+	/*
+	 *	FIXME: Discard the packet & listen for another.
+	 *
+	 *	Hmm... we should really be using eapol_test, which does
+	 *	a lot more than radeapclient.
+	 */
 	if (rad_decode(*rep, req, secret) != 0) {
 		librad_perror("rad_decode");
 		exit(1);
@@ -950,7 +955,7 @@ int main(int argc, char **argv)
 			timeout = atof(optarg);
 			break;
 		case 'v':
-			printf("radclient: $Id: radeapclient.c,v 1.7.4.1 2005/12/14 18:32:02 nbk Exp $ built on " __DATE__ " at " __TIME__ "\n");
+			printf("radclient: $Id: radeapclient.c,v 1.7.4.2 2006/02/06 16:23:51 nbk Exp $ built on " __DATE__ " at " __TIME__ "\n");
 			exit(0);
 			break;
                case 'S':
