@@ -1,7 +1,7 @@
 /*
  * rlm_eap_tls.c  contains the interfaces that are called from eap
  *
- * Version:     $Id: rlm_eap_tls.c,v 1.21.4.1 2005/12/15 00:06:26 aland Exp $
+ * Version:     $Id: rlm_eap_tls.c,v 1.21.4.2 2006/02/06 15:37:03 nbk Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -533,7 +533,7 @@ static int eaptls_authenticate(void *arg UNUSED, EAP_HANDLER *handler)
 			unsigned int data_len;
 			unsigned char buffer[1024];
 
-			data_len = record_minus(&tls_session->dirty_in,
+			data_len = (tls_session->record_minus)(&tls_session->dirty_in,
 						buffer, sizeof(buffer));
 			log_debug("  Tunneled data (%u bytes)\n", data_len);
 			for (i = 0; i < data_len; i++) {
