@@ -1,7 +1,7 @@
 /*
  * rlm_files.c	authorization: Find a user in the "users" file.
  *
- * Version:	$Id: rlm_files.c,v 1.61 2004/03/12 16:12:53 aland Exp $
+ * Version:	$Id: rlm_files.c,v 1.61.2.1 2004/10/20 17:14:38 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
  * Copyright 2000  Jeff Carneal <jeff@apex.net>
  */
 
-static const char rcsid[] = "$Id: rlm_files.c,v 1.61 2004/03/12 16:12:53 aland Exp $";
+static const char rcsid[] = "$Id: rlm_files.c,v 1.61.2.1 2004/10/20 17:14:38 aland Exp $";
 
 #include	"autoconf.h"
 #include	"libradius.h"
@@ -335,10 +335,10 @@ static int file_authorize(void *instance, REQUEST *request)
 				pairmove(check_pairs, &check_tmp);
 				pairfree(&check_tmp);
 
-				DEBUG2("    users: Checking %s at %d", pl->name, pl->lineno);
+				DEBUG2("    users: Checking entry %s at line %d", pl->name, pl->lineno);
 				/* Check the req to see if we matched */
 				if (rad_check_password(request)==0) {
-					DEBUG2("    users: Matched %s at %d", pl->name, pl->lineno);
+					DEBUG2("    users: Matched entry %s at line %d", pl->name, pl->lineno);
 
 					found = 1;
 
@@ -365,7 +365,7 @@ static int file_authorize(void *instance, REQUEST *request)
 			/* No usercollide */
 			} else {
 
-				DEBUG2("    users: Matched %s at %d", pl->name, pl->lineno);
+				DEBUG2("    users: Matched entry %s at line %d", pl->name, pl->lineno);
 				found = 1;
 				check_tmp = paircopy(pl->check);
 				reply_tmp = paircopy(pl->reply);
@@ -432,7 +432,7 @@ static int file_preacct(void *instance, REQUEST *request)
 			continue;
 
 		if (paircmp(request, request_pairs, pl->check, reply_pairs) == 0) {
-			DEBUG2("    acct_users: Matched %s at %d",
+			DEBUG2("    acct_users: Matched entry %s at line %d",
 			       pl->name, pl->lineno);
 			found = 1;
 			check_tmp = paircopy(pl->check);
@@ -497,7 +497,7 @@ static int file_preproxy(void *instance, REQUEST *request)
 		if (paircmp(request, request_pairs, pl->check, reply_pairs) == 0) {
 			VALUE_PAIR *vp;
 
-			DEBUG2("    preproxy_users: Matched %s at %d",
+			DEBUG2("    preproxy_users: Matched entry %s at line %d",
 			       pl->name, pl->lineno);
 			found = 1;
 			check_tmp = paircopy(pl->check);
