@@ -1,6 +1,6 @@
 /*
  * otp_cardops.c
- * $Id: otp_cardops.c,v 1.62.2.1 2005/12/08 01:30:50 fcusack Exp $
+ * $Id: otp_cardops.c,v 1.62.2.2 2006/03/03 00:58:32 fcusack Exp $
  *
  * Passcode verification functions for otp.
  *
@@ -23,7 +23,7 @@
  * Copyright 2005 TRI-D Systems, Inc.
  */
 
-static const char rcsid[] = "$Id: otp_cardops.c,v 1.62.2.1 2005/12/08 01:30:50 fcusack Exp $";
+static const char rcsid[] = "$Id: otp_cardops.c,v 1.62.2.2 2006/03/03 00:58:32 fcusack Exp $";
 
 #if defined(__linux__) && !defined(_GNU_SOURCE)
 #define _GNU_SOURCE	/* RTLD_DEFAULT */
@@ -229,13 +229,17 @@ async_response:
     ssize_t chal_len;
 
     /* Perform any site-specific transforms of the challenge. */
-    if ((chal_len = otp_challenge_transform(username,
-                                            challenge, opt->chal_len)) < 0) {
-      otp_log(OTP_LOG_ERR, "%s: %s: challenge transform failed for [%s]",
-              log_prefix, __func__, username);
-      rc = OTP_RC_SERVICE_ERR;
-      goto auth_done_service_err;
-      /* NB: state not updated. */
+    if (opt->site_transform) {
+      if ((chal_len = otp_challenge_transform(username,
+                                              challenge, opt->chal_len)) < 0) {
+        otp_log(OTP_LOG_ERR, "%s: %s: challenge transform failed for [%s]",
+                log_prefix, __func__, username);
+        rc = OTP_RC_SERVICE_ERR;
+        goto auth_done_service_err;
+        /* NB: state not updated. */
+      }
+    } else {
+      chal_len = opt->chal_len;
     }
 
     /* Calculate the async response. */
