@@ -1,7 +1,7 @@
 /*
  * rlm_perl.c
  *
- * Version:    $Id: rlm_perl.c,v 1.13.4.3 2006/01/10 11:46:24 nbk Exp $
+ * Version:    $Id: rlm_perl.c,v 1.13.4.4 2006/03/17 19:49:55 aland Exp $
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@
 extern char **environ;
 #endif
 
-static const char rcsid[] = "$Id: rlm_perl.c,v 1.13.4.3 2006/01/10 11:46:24 nbk Exp $";
+static const char rcsid[] = "$Id: rlm_perl.c,v 1.13.4.4 2006/03/17 19:49:55 aland Exp $";
 
 #ifdef USE_ITHREADS
 
@@ -778,7 +778,7 @@ static int perl_instantiate(CONF_SECTION *conf, void **instance)
 	}
 
 #ifdef USE_ITHREADS
-	inst->perl = perl_clone(interp ,CLONEf_KEEP_PTR_TABLE);
+	inst->perl = interp;
 	{
 	dTHXa(inst->perl);
 	}
